==> scalarx_2.10-0.2.3-JS.jar: rx/core/Obs$.js <==
/** @constructor */
ScalaJS.c.rx_core_Obs$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Obs$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Obs$.prototype.constructor = ScalaJS.c.rx_core_Obs$;
ScalaJS.c.rx_core_Obs$.prototype.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs = (function(es, name, skipInitial, callback) {
  return new ScalaJS.c.rx_core_Obs().init___Lrx_core_Emitter__Lscala_Function0__T__Z(es, callback, name, skipInitial)
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$3__Z = (function() {
  return false
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$3__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$4__Z = (function() {
  return false
});
ScalaJS.c.rx_core_Obs$.prototype.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__ = (function(es, name, skipInitial, callback) {
  return this.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs(es, name, skipInitial, callback)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Obs$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Obs$.prototype = ScalaJS.c.rx_core_Obs$.prototype;
ScalaJS.is.rx_core_Obs$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Obs$)))
});
ScalaJS.as.rx_core_Obs$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Obs$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Obs")
  }
});
ScalaJS.isArrayOf.rx_core_Obs$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Obs$)))
});
ScalaJS.asArrayOf.rx_core_Obs$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Obs$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Obs;", depth)
  }
});
ScalaJS.data.rx_core_Obs$ = new ScalaJS.ClassTypeData({
  rx_core_Obs$: 0
}, false, "rx.core.Obs$", ScalaJS.data.java_lang_Object, {
  rx_core_Obs$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Obs$.prototype.$classData = ScalaJS.data.rx_core_Obs$;
ScalaJS.moduleInstances.rx_core_Obs = undefined;
ScalaJS.modules.rx_core_Obs = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Obs)) {
    ScalaJS.moduleInstances.rx_core_Obs = new ScalaJS.c.rx_core_Obs$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Obs
});
//@ sourceMappingURL=Obs$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/core/Obs$.js <==
/** @constructor */
ScalaJS.c.rx_core_Obs$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Obs$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Obs$.prototype.constructor = ScalaJS.c.rx_core_Obs$;
ScalaJS.c.rx_core_Obs$.prototype.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs = (function(es, name, skipInitial, callback) {
  return new ScalaJS.c.rx_core_Obs().init___Lrx_core_Emitter__Lscala_Function0__T__Z(es, callback, name, skipInitial)
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$3__Z = (function() {
  return false
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$3__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$4__Z = (function() {
  return false
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$3__ = (function() {
  return ScalaJS.bZ(this.apply$default$3__Z())
});
ScalaJS.c.rx_core_Obs$.prototype.apply$default$2__ = (function() {
  return this.apply$default$2__T()
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$4__ = (function() {
  return ScalaJS.bZ(this.$$lessinit$greater$default$4__Z())
});
ScalaJS.c.rx_core_Obs$.prototype.$$lessinit$greater$default$3__ = (function() {
  return this.$$lessinit$greater$default$3__T()
});
ScalaJS.c.rx_core_Obs$.prototype.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__ = (function(es, name, skipInitial, callback) {
  return this.apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs(es, name, skipInitial, callback)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Obs$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Obs$.prototype = ScalaJS.c.rx_core_Obs$.prototype;
ScalaJS.is.rx_core_Obs$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Obs$)))
});
ScalaJS.as.rx_core_Obs$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Obs$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Obs")
  }
});
ScalaJS.isArrayOf.rx_core_Obs$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Obs$)))
});
ScalaJS.asArrayOf.rx_core_Obs$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Obs$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Obs;", depth)
  }
});
ScalaJS.data.rx_core_Obs$ = new ScalaJS.ClassTypeData({
  rx_core_Obs$: 0
}, false, "rx.core.Obs$", ScalaJS.data.java_lang_Object, {
  rx_core_Obs$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Obs$.prototype.$classData = ScalaJS.data.rx_core_Obs$;
ScalaJS.moduleInstances.rx_core_Obs = undefined;
ScalaJS.modules.rx_core_Obs = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Obs)) {
    ScalaJS.moduleInstances.rx_core_Obs = new ScalaJS.c.rx_core_Obs$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Obs
});
//@ sourceMappingURL=Obs$.js.map
